eric7/E5XML/XMLStreamWriterBase.py

branch
eric7
changeset 8314
e3642a6a1e71
parent 8312
800c432b34c8
child 8318
962bce857696
--- a/eric7/E5XML/XMLStreamWriterBase.py	Sat May 15 19:01:16 2021 +0200
+++ b/eric7/E5XML/XMLStreamWriterBase.py	Sat May 15 20:08:03 2021 +0200
@@ -4,7 +4,7 @@
 #
 
 """
-Module implementing a base class for all of eric6s XML stream writers.
+Module implementing a base class for all of eric7s XML stream writers.
 """
 
 import pickle           # secok
@@ -15,7 +15,7 @@
 
 class XMLStreamWriterBase(QXmlStreamWriter):
     """
     Class implementing a base class for all of eric6s XML stream writers.
     """
     def __init__(self, device):
         """
@@ -15,7 +15,7 @@
 class XMLStreamWriterBase(QXmlStreamWriter):
     """
-    Class implementing a base class for all of eric6s XML stream writers.
+    Class implementing a base class for all of eric7s XML stream writers.
     """
     def __init__(self, device):

eric ide

mercurial